Learn R Programming

retroharmonize (version 0.2.0)

suggest_permanent_names: Suggest permanent names

Description

Suggest the use of established naming conventions.

Usage

suggest_permanent_names(survey_program = "eurobarometer")

Arguments

survey_program

Suggest permanent names for the survey progarm "eurobarometer"

Value

A character vector with suggested permanent names.

Details

Established survey programs usually have their own variable name conventions. The suggested constant names keep these variable names constant.

See Also

Other harmonization functions: collect_val_labels(), harmonize_na_values(), harmonize_values(), harmonize_var_names(), label_normalize(), suggest_var_names()

Examples

Run this code
# NOT RUN {
suggest_permanent_names ( "eurobarometer" )
# }

Run the code above in your browser using DataLab