powered by
Suggest the use of established naming conventions.
suggest_permanent_names(survey_program = "eurobarometer")
Suggest permanent names for the survey progarm "eurobarometer"
"eurobarometer"
A character vector with suggested permanent names.
Established survey programs usually have their own variable name conventions. The suggested constant names keep these variable names constant.
Other harmonization functions: collect_val_labels(), harmonize_na_values(), harmonize_values(), harmonize_var_names(), label_normalize(), suggest_var_names()
collect_val_labels()
harmonize_na_values()
harmonize_values()
harmonize_var_names()
label_normalize()
suggest_var_names()
# NOT RUN { suggest_permanent_names ( "eurobarometer" ) # }
Run the code above in your browser using DataLab